@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: semigroupoids
 version: 5.0.1
-id: semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
-key: semig_HuvOh8WT5cqAWrgFYvgUVV
+id: semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
+key: semig_2toHfd7IuEfBrs937RnHBy
 license: BSD3
 copyright: Copyright (C) 2011-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -59,15 +59,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroupoids-5.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroupoids-5.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroupoids-5.0.1
-hs-libraries: HSsemigroupoids-5.0.1-HuvOh8WT5cqAWrgFYvgUVV
+hs-libraries: HSsemigroupoids-5.0.1-2toHfd7IuEfBrs937RnHBy
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    base-orphans-0.5.1-066f51369735933a8c1cc4e054dd01ca
-    bifunctors-5.2.1-f15ad2d16f9be29f17cf3cf758fe7ba6
-    comonad-5-530ea4e1d08a0115920b946124e760ac
+    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
+    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
+    comonad-5-a91321d086a2de4a04a44d60c347669e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
-    distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
+    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
